#ifndef NT2_INCLUDE_FUNCTIONS_ISEQUALN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISEQUALN_HPP_INCLUDED

#include <nt2/predicates/include/functions/isequaln.hpp>

#endif
